# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_rpm.api.content_modulemd_defaults_api import ContentModulemdDefaultsApi


class TestContentModulemdDefaultsApi(unittest.TestCase):
    """ContentModulemdDefaultsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ContentModulemdDefaultsApi()

    def tearDown(self) -> None:
        pass

    def test_create(self) -> None:
        """Test case for create

        Create a modulemd defaults
        """
        pass

    def test_list(self) -> None:
        """Test case for list

        List modulemd defaultss
        """
        pass

    def test_read(self) -> None:
        """Test case for read

        Inspect a modulemd defaults
        """
        pass

    def test_set_label(self) -> None:
        """Test case for set_label

        Set a label
        """
        pass

    def test_unset_label(self) -> None:
        """Test case for unset_label

        Unset a label
        """
        pass


if __name__ == '__main__':
    unittest.main()
